@@ -33,15 +33,6 @@ class Turba_Test extends Horde_Test
      */
     protected $_pearList = array();
 
-    /**
-     * Required configuration files.
-     *
-     * @var array
-     */
-    protected $_fileList = array(
-        'config/conf.php' => null,
-    );
-
     /**
      * Inter-Horde application dependencies.
      *
@@ -49,6 +40,20 @@ class Turba_Test extends Horde_Test
      */
     protected $_appList = array();
 
+    /**
+     */
+    public function __construct()
+    {
+        parent::__construct();
+
+        $this->_fileList += array(
+            'config/attributes.php' => null,
+            'config/backends.php' => null,
+            'config/mime_drivers.php' => null,
+            'config/prefs.php' => null
+        );
+    }
+
     /**
      * Any application specific tests that need to be done.
      *
